@@ -19,32 +19,29 @@ Functionally similar to:
 
 | $ snmptrap -v1 -c public demo.pysnmp.com 1.3.6.1.4.1.20408.4.1.1.2 0.0.0.0 1 0 0 1.3.6.1.2.1.1.1.0 s "my system"
 
-"""#
+"""  #
 import asyncio
 from pysnmp.hlapi.asyncio import *
 
 
-@asyncio.coroutine
-def run():
+async def run():
     snmpEngine = SnmpEngine()
-    errorIndication, errorStatus, errorIndex, varBinds = yield from sendNotification(
+    trap_result = await sendNotification(
         snmpEngine,
         CommunityData('public', mpModel=0),
         UdpTransportTarget(('demo.pysnmp.com', 162)),
         ContextData(),
-        'trap',
-        NotificationType(
-            ObjectIdentity('1.3.6.1.6.3.1.1.5.2')
-        ).addVarBinds(
-            ('1.3.6.1.6.3.1.1.4.3.0', '1.3.6.1.4.1.20408.4.1.1.2'),
-            ('1.3.6.1.2.1.1.1.0', OctetString('my system'))
-        )
+        "trap",
+        NotificationType(ObjectIdentity("1.3.6.1.6.3.1.1.5.2")).addVarBinds(
+            ("1.3.6.1.6.3.1.1.4.3.0", "1.3.6.1.4.1.20408.4.1.1.2"),
+            ("1.3.6.1.2.1.1.1.0", OctetString("my system")),
+        ),
     )
-
+    errorIndication, errorStatus, errorIndex, varBinds = await trap_result
     if errorIndication:
         print(errorIndication)
 
     snmpEngine.transportDispatcher.closeDispatcher()
 
 
-asyncio.get_event_loop().run_until_complete(run())
+asyncio.run(run())
